# JELSR
Unsupervised Feature Selection of Joint Embedding Sparse Regression Analysis.
# Summary
The function JELSR follows the paper "Joint Embedding Learning and Sparse Regression: A Framework for Unsupervised Feature Selection"(2014) by  Chenping Hou, Feiping Nie, Xuelong Li, Dongyun Yi and Yi Wu

# Why a new package
The JELSR feature selection approach is of great importance and is one of the most popular approaches in feature selection of unsupervised clustering problem.

The Package closely follows the paper and enables users to choose key parameters in the algrithm. It would be helpful to people interested in the method and could be directly applied to numpy array dataset.

The paper is relative new and no existing package designed for JELSR in python yet.

# Reference
"Joint Embedding Learning and Sparse Regression: A Framework for Unsupervised Feature Selection"(2014) by  Chenping Hou, Feiping Nie, Xuelong Li, Dongyun Yi and Yi Wu


